@@ -294,7 +294,7 @@ describe 'ceilometer' do
       end
 
       let :platform_params do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :common_package_name => 'ceilometer-common' }
         when 'RedHat'
